@@ -17,10 +17,13 @@ signals:
 
 
 private:
+    void closeEvent(QCloseEvent *event);
     QStandardItemModel *model;
     QListView *lstExercises;
     QPushButton *btnStart;
 
+    bool closing;
+
 private slots:
     void start();
 
