@@ -123,11 +123,11 @@ void FoodWindow::load()
     tmp.setNum(remaining);
 
     if(remaining >= 0)
-        lblCalories->setText("You have eaten " + kcal + " kcal today (" + tmp + " left). \nYour mean kcal/day is 2800 kcal " +
+        lblCalories->setText("You have eaten " + kcal + " kcal today (" + tmp + " left)." +
                              "\nProtein: " + protein + "g. Carbohydrate: " + carbohydrate + "g. Fat: " +
                              fat + "g.");
     else
-        lblCalories->setText("You have eaten to much today. \nYour mean kcal/day is 2800 kcal");
+        lblCalories->setText("You have eaten to much today. \n");
 
 
 }
