@@ -27,28 +27,16 @@ private:
     QPushButton *btnSave;
 
     QStandardItemModel *modelSet;
-    QStandardItemModel *modelReps1;
-    QStandardItemModel *modelReps2;
-    QStandardItemModel *modelReps3;
     QStandardItemModel *modelMin;
     QStandardItemModel *modelSec;
-    QStandardItemModel *modelCurrentReps;
 
 
     QMaemo5ValueButton *btnSet;
-    QMaemo5ValueButton *btnReps1;
-    QMaemo5ValueButton *btnReps2;
-    QMaemo5ValueButton *btnReps3;
-    QMaemo5ValueButton *btnCurrentReps;
     QMaemo5ValueButton *btnMin;
     QMaemo5ValueButton *btnSec;
 
 
     QMaemo5ListPickSelector *selectorSet;
-    QMaemo5ListPickSelector *selectorReps1;
-    QMaemo5ListPickSelector *selectorReps2;
-    QMaemo5ListPickSelector *selectorReps3;
-    QMaemo5ListPickSelector *selectorCurrentReps;
     QMaemo5ListPickSelector *selectorMin;
     QMaemo5ListPickSelector *selectorSec;
 
