@@ -189,8 +189,10 @@ void XML::saveProgram(QString name, QModelIndexList exercises)
       {
         if( e.tagName() == "programs" )
         {
+            qDebug () << "XML::saveProgram" << e.attribute( "name", "" );
             if(name == e.attribute( "name", "" ))
             {
+                qDebug() << "XML::saveProgram: remove";
                 removeProgram(name);
             }
         }
@@ -209,7 +211,9 @@ void XML::saveProgram(QString name, QModelIndexList exercises)
     {
         root = doc.createElement( "programs" );
         doc.appendChild( root );
+        qDebug() << "XML::saveProgram: create root";
     }
+
     file.remove();
     file.close();
     root.appendChild(createProgramNode(doc, name, exercises));
