@@ -15,7 +15,7 @@ public:
     void saveSettings(QString vibrate, QString sound, QString volume
                       ,QString set, QString min, QString sec, QString calories);
     void saveEx(QString name, QString group, QString muscle,
-                   QString info);
+                   QString info, QString newName = "0");
     QList <QString> loadSettings();
     QList<QString> openAll();
 
